==> kadaster-gds2-2.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Afgifte_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", "Afgifte");
    private final static QName _BestandenLijst_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", "BestandenLijst");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteType }
     * 
     */
    public AfgifteType createAfgifteType() {
        return new AfgifteType();
    }

    /**
     * Create an instance of {@link BestandenLijstType }
     * 
     */
    public BestandenLijstType createBestandenLijstType() {
        return new BestandenLijstType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", name = "Afgifte")
    public JAXBElement<AfgifteType> createAfgifte(AfgifteType value) {
        return new JAXBElement<AfgifteType>(_Afgifte_QNAME, AfgifteType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", name = "BestandenLijst")
    public JAXBElement<BestandenLijstType> createBestandenLijst(BestandenLijstType value) {
        return new JAXBElement<BestandenLijstType>(_BestandenLijst_QNAME, BestandenLijstType.class, null, value);
    }

}

==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Afgifte_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", "Afgifte");
    private final static QName _BestandenLijst_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", "BestandenLijst");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteType }
     * 
     */
    public AfgifteType createAfgifteType() {
        return new AfgifteType();
    }

    /**
     * Create an instance of {@link BestandenLijstType }
     * 
     */
    public BestandenLijstType createBestandenLijstType() {
        return new BestandenLijstType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", name = "Afgifte")
    public JAXBElement<AfgifteType> createAfgifte(AfgifteType value) {
        return new JAXBElement<AfgifteType>(_Afgifte_QNAME, AfgifteType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401", name = "BestandenLijst")
    public JAXBElement<BestandenLijstType> createBestandenLijst(BestandenLijstType value) {
        return new JAXBElement<BestandenLijstType>(_BestandenLijst_QNAME, BestandenLijstType.class, null, value);
    }

}
